@@ -38,7 +38,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 	
 );
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 
 # Preloaded methods go here.
@@ -717,7 +717,8 @@ T.M. Brannon <tbone@cpan.org>
 
 =head1 SEE ALSO
 
-perl(1).
+L<Data::Walker|Data::Walker>,
+L<Data::Match|Data::Match>, L<Data::Compare|Data::Compare>
 
 =cut
 
